@@ -2,8 +2,10 @@
 
 package DD;
 
-our $DATE = '2019-08-01'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2019-08-08'; # DATE
+our $DIST = 'DD'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 use Exporter qw(import);
 our @EXPORT = qw(dd dmp);
@@ -80,7 +82,7 @@ DD - Dump data structure for debugging
 
 =head1 VERSION
 
-This document describes version 0.002 of DD (from Perl distribution DD), released on 2019-08-01.
+This document describes version 0.003 of DD (from Perl distribution DD), released on 2019-08-08.
 
 =head1 SYNOPSIS
 
